From da60a6d786ed9b6e847e8abb1deeec1c14605ba3 Mon Sep 17 00:00:00 2001
From: Eric Cooper <ecc@cmu.edu>
Date: Tue, 11 Nov 2008 12:41:56 -0500
Subject: [PATCH] handle multiple blank lines between paragraphs in control files

---
 control_file.ml |   30 ++++++++++++++++++------------
 1 files changed, 18 insertions(+), 12 deletions(-)

diff --git a/control_file.ml b/control_file.ml
index 90b8e89..3dbae7e 100644
--- a/control_file.ml
+++ b/control_file.ml
@@ -45,18 +45,24 @@ let read_paragraph chan =
       with End_of_file -> None
     in
     match next with
-    | None when lines = [] -> raise End_of_file
-    | None | Some "" -> lines
-    | Some line when line.[0] = ' ' || line.[0] = '\t' ->
-        (match lines with
-        | last :: others ->
-            let line =
-              if line = " ." then ""
-              else substring line ~from: 1
-            in
-            loop ((last ^ "\n" ^ line) :: others)
-        | [] -> failwith ("leading white space: " ^ line))
-    | Some line -> loop (line :: lines)
+    | None ->
+        if lines <> [] then lines
+        else raise End_of_file
+    | Some "" ->
+        if lines <> [] then lines
+        else loop []
+    | Some line ->
+        if line.[0] = ' ' || line.[0] = '\t' then
+          match lines with
+          | last :: others ->
+              let line =
+                if line = " ." then ""
+                else substring line ~from: 1
+              in
+              loop ((last ^ "\n" ^ line) :: others)
+          | [] -> failwith ("leading white space: " ^ line)
+        else
+          loop (line :: lines)
   in
   List.rev_map parse (loop [])
 
-- 
1.5.6.5

